@@ -62,10 +62,7 @@ def is_invalid_relative_regex_mapping(relative_regex_mapping):
     key, value = relative_regex_mapping
     if not (key and value and isinstance(key, str) and isinstance(value, list)):
         return True
-    if '\\1' not in key:
-        return True
-    return not (all([isinstance(x, str) for x in value])
-                and all(['(\\d+[.,]?\\d*)' in x for x in value]))
+    return not all([isinstance(x, str) for x in value])
 
 
 class TestLocaleInfo(BaseTestCase):
